%global with_python3 1

Name:           udiskie
Version:        1.2.0
Release:        1%{?dist}
Summary:        Removable disk auto-mounter

License:        MIT
URL:            https://pypi.python.org/pypi/%{name}
Source0:        https://pypi.python.org/packages/source/u/%{name}/%{name}-%{version}.tar.gz

BuildArch:      noarch
BuildRequires:  asciidoc gettext
BuildRequires:  python2-devel python-setuptools
%if 0%{?with_python3}
BuildRequires:  python3-devel python3-setuptools
%endif # with_python3

# Require the module for the correct python
%if 0%{with_python3}
%if 0%{?fedora} > 21
Requires: python3-%{name}
%else
Requires: python-%{name}
%endif # fedora > 21
%else
Requires: python-%{name}
%endif # with_python3

%description
%{name} is a front-end for UDisks written in python. Its main purpose is
automatically mounting removable media, such as CDs or flash drives. It has
optional mount notifications, a GTK tray icon and user level CLIs for manual
mounting and unmounting operations.

# Define packaged required by both python versions
%global shared_requires udisks2 gobject-introspection gtk3 libnotify

%package -n python-%{name}
Summary: Python 2 module for %{name} disk automounter
Requires: %{shared_requires}
Requires: pygobject3 python-docopt PyYAML

%description -n python-%{name}
%{name} is a front-end for UDisks written in python. This package provides the
python 2 modules used by the %{name} binaries.

%if 0%{?with_python3}
%package -n python3-%{name}
Summary: Python 3 module for udisks disk automounting
Requires: %{shared_requires}
Requires: python3-gobject python3-docopt python3-PyYAML

%description -n python3-%{name}
%{name} is a front-end for UDisks written in python. This package provides the 
python 3 modules used by the %{name} binaries.

%endif # with_python3

%prep
%setup -qc
mv %{name}-%{version} python2
pushd python2

find -name '*.txt' | xargs chmod -x
# Copy common doc files to the top dir
cp -prt.. doc CONTRIBUTORS COPYING README.rst
popd

%if 0%{with_python3}
cp -a python2 python3
find python3 -name '*.py' | xargs sed -i 's|^#!python|#!%{__python3}|'
%endif # with_python3

find python2 -name '*.py' | xargs sed -i 's|^#!python|#!%{__python2}|'

%build
pushd python2
CFLAGS="%{optflags}" %{__python2} setup.py build
popd

%if 0%{with_python3}
pushd python3
CFLAGS="%{optflags}" LC_ALL="en_US.utf8" %{__python3} setup.py build
popd
%endif # with_python3

# Build man page
make %{?_smp_mflags} -C doc && gzip doc/%{name}.8

%install
rm -rf %{buildroot}

# Define functions for installing both python2 and python3, then use in desired order
function install_py2
{
  pushd python2
  %{__python2} setup.py install --skip-build --root %{buildroot}
  popd

  find %{buildroot}%{python2_sitelib} -name '*.exe' | xargs rm -f
}
function install_py3
{
  pushd python3
  LC_ALL="en_US.utf8" %{__python3} setup.py install --skip-build --root %{buildroot}
  popd

  find %{buildroot}%{python3_sitelib} -name '*.exe' | xargs rm -f
}

%if 0%{with_python3}
%if 0%{?fedora} > 21
install_py2; install_py3
%else
install_py3; install_py2
%endif # fedra > 21
%else # with_python3
install_py2
%endif

# Install man page
install -d %{buildroot}%{_mandir}/man8
install -m644 -t %{buildroot}%{_mandir}/man8 doc/%{name}.8.gz
# Create man pages for other binaries
for other in %{name}-mount %{name}-umount; do
  echo ".so man8/%{name}.8" | gzip > %{buildroot}%{_mandir}/man8/"${other}.8.gz"
done

# Find all localization files
%find_lang %{name}

%check
pushd python2
%{__python2} setup.py test
popd

%if 0%{with_python3}
pushd python3
LC_ALL="en_US.utf8" %{__python3} setup.py test
popd
%endif # with_python3

# Update icon cache
# https://fedoraproject.org/wiki/Packaging:ScriptletSnippets#Icon_Cache
%post
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :

%files -f %{name}.lang
%doc %{_mandir}/man8/*.8.gz
%doc CONTRIBUTORS README.rst
%license COPYING
%{_bindir}/%{name}
%{_bindir}/%{name}-mount
%{_bindir}/%{name}-umount
%{_datadir}/icons/*

%files -n python-%{name}
%doc CONTRIBUTORS README.rst
%license COPYING
%{python2_sitelib}/*

%if 0%{with_python3}
%files -n python3-%{name}
%doc CONTRIBUTORS README.rst
%license COPYING
%{python3_sitelib}/*
%endif # with_python3


%changelog
* Thu May 21 2015 Jan Stanek <jstanek@redhat.com> - 1.2.0-1
- Initial package
